@@ -1,4 +1,8 @@
+import pkg_resources
+
 from redio import commands, conn, conv, exc, highlevel, pubsub, protocol
 from redio.highlevel import Redis
 
-__version__ = "0.4.1"
+__version__ = pkg_resources.require(__name__)[0].version
+
+del pkg_resources
